==> golang-github-urfave-cli-v2_2.25.7.orig.tar.gz: cli-2.25.7/.github/ISSUE_TEMPLATE/v1-bug-report.md <==
---
name: v1 bug report
about: Create a report to help us fix v1 bugs
title: 'your bug title goes here'
labels: 'kind/bug, status/triage, area/v1'
assignees: ''

---

## My urfave/cli version is

_**( Put the version of urfave/cli that you are using here )**_

## Checklist

- [ ] Are you running the latest v1 release? The list of releases is [here](https://github.com/urfave/cli/releases).
- [ ] Did you check the manual for your release? The v1 manual is [here](https://github.com/urfave/cli/blob/main/docs/v1/manual.md).
- [ ] Did you perform a search about this problem? Here's the [GitHub guide](https://help.github.com/en/github/managing-your-work-on-github/using-search-to-filter-issues-and-pull-requests) about searching.

## Dependency Management

<!--
  Delete any of the following that do not apply:
-->

- My project is using go modules.
- My project is using vendoring.
- My project is automatically downloading the latest version.
- I am unsure of what my dependency management setup is.

## Describe the bug

A clear and concise description of what the bug is.

## To reproduce

Describe the steps or code required to reproduce the behavior

## Observed behavior

What did you see happen immediately after the reproduction steps
above?

## Expected behavior

What would you have expected to happen immediately after the
reproduction steps above?

## Additional context

Add any other context about the problem here.

If the issue relates to a specific open source GitHub repo, please
link that repo here.

If you can reproduce this issue with a public CI system, please
link a failing build here.

## Want to fix this yourself?

We'd love to have more contributors on this project! If the fix for
this bug is easily explained and very small, feel free to create a
pull request for it. You'll want to base the PR off the `v1`
branch, all `v1` bug fix releases will be made from that branch.

## Run `go version` and paste its output here

```
# paste `go version` output in here
```

## Run `go env` and paste its output here

```
# paste `go env` output in here
```

==> golang-github-urfave-cli-v3_3.3.8.orig.tar.gz: cli-3.3.8/.github/ISSUE_TEMPLATE/v1-bug-report.md <==
---
name: v1 bug report
about: Create a report to help us fix v1 bugs
title: 'your bug title goes here'
labels: 'kind/bug, status/triage, area/v1'
assignees: ''

---

## My urfave/cli version is

_**( Put the version of urfave/cli that you are using here )**_

## Checklist

- [ ] Are you running the latest v1 release? The list of releases is [here](https://github.com/urfave/cli/releases).
- [ ] Did you check the manual for your release? The v1 manual is [here](https://cli.urfave.org/v1/getting-started/).
- [ ] Did you perform a search about this problem? Here's the [GitHub guide](https://help.github.com/en/github/managing-your-work-on-github/using-search-to-filter-issues-and-pull-requests) about searching.

## Dependency Management

<!--
  Delete any of the following that do not apply:
-->

- My project is using go modules.
- My project is using vendoring.
- My project is automatically downloading the latest version.
- I am unsure of what my dependency management setup is.

## Describe the bug

A clear and concise description of what the bug is.

## To reproduce

Describe the steps or code required to reproduce the behavior

## Observed behavior

What did you see happen immediately after the reproduction steps
above?

## Expected behavior

What would you have expected to happen immediately after the
reproduction steps above?

## Additional context

Add any other context about the problem here.

If the issue relates to a specific open source GitHub repo, please
link that repo here.

If you can reproduce this issue with a public CI system, please
link a failing build here.

## Want to fix this yourself?

We'd love to have more contributors on this project! If the fix for
this bug is easily explained and very small, feel free to create a
pull request for it. You'll want to base the PR off the `v1`
branch, all `v1` bug fix releases will be made from that branch.

## Run `go version` and paste its output here

```
# paste `go version` output in here
```

## Run `go env` and paste its output here

```
# paste `go env` output in here
```
